#ifndef NT2_INCLUDE_FUNCTIONS_LEGENDRE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LEGENDRE_HPP_INCLUDED

#include <nt2/polynomials/include/functions/legendre.hpp>

#endif
